@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper;
-$Test::Mock::Wrapper::VERSION = '0.11';
+$Test::Mock::Wrapper::VERSION = '0.12';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -28,7 +28,7 @@ Test::Mock::Wrapper
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -174,7 +174,7 @@ sub new {
 		$metaclass->add_method($method_name, sub{
 		    my $copy = $controll->{__options}{recordType} eq 'copy' ? [@_] : clone(@_);
 		    push @{ $controll->{__calls}{new} }, $copy;
-		    my $obj = bless {}, $object;
+		    my $obj = bless {_inst => scalar(@{ $controll->{__calls}{new} })}, $object;
 		    push @{ $controll->{__instances} }, $obj;
 		    return $obj;
 		});
@@ -422,7 +422,7 @@ sub resetAll {
 
 
 package Test::Mock::Wrapper::Method;
-$Test::Mock::Wrapper::Method::VERSION = '0.11';
+$Test::Mock::Wrapper::Method::VERSION = '0.12';
 use Test::Deep;
 use strict;
 use warnings;
@@ -444,16 +444,21 @@ sub addMock {
 
 sub hasMock {
     my($self, @args) = @_;
+    my $def = undef;
     foreach my $mock (@{$self->{_mocks}}){
 	if ($mock->_matches(@args)) {
-	    return $mock;
+	    if ($mock->_isDefault) {
+		$def = $mock;
+	    }else{
+		return $mock;
+	    }
 	}
     }
-    return undef;
+    return $def;
 }
 
 package Test::Mock::Wrapper::Method::Mock;
-$Test::Mock::Wrapper::Method::Mock::VERSION = '0.11';
+$Test::Mock::Wrapper::Method::Mock::VERSION = '0.12';
 use Test::Deep;
 use strict;
 use warnings;
@@ -485,7 +490,7 @@ sub returns {
 
 sub _isDefault {
     my($self) = @_;
-    return exists($self->{_condition});
+    return ! exists($self->{_condition});
 }
 
 sub _matches {
@@ -511,7 +516,7 @@ sub _fetchReturn {
 
 
 package Test::Mock::Wrapped;
-$Test::Mock::Wrapped::VERSION = '0.11';
+$Test::Mock::Wrapped::VERSION = '0.12';
 use strict;
 use warnings;
 use Carp;
